import crypto from 'crypto';
import read from 'read';
// A helper function that can be used to read the passphrase to decrypt a
// password-decrypted private key.
export async function readPassphrase() {
    try {
        const passphrase = await read({
            prompt: 'Passphrase for the key: ',
            silent: true,
            replace: '*',
            // Output must be != `stdout`. Otherwise saving the `wbn-dump-id`
            // result into a file or an environment variable also includes the prompt.
            output: process.stderr,
        });
        return passphrase;
    }
    catch (er) {
        throw new Error('Reading passphrase failed.');
    }
}
// A helper function which can be used to parse string formatted keys to
// KeyObjects.
export function parsePemKey(unparsedKey, passphrase) {
    return crypto.createPrivateKey({
        key: unparsedKey,
        passphrase,
    });
}
export function getRawPublicKey(publicKey) {
    // Currently this is the only way for us to get the raw 32 bytes of the public key.
    return new Uint8Array(publicKey.export({ type: 'spki', format: 'der' }).slice(-32));
}
// Throws an error if the key is not a valid Ed25519 key of the specified type.
export function checkIsValidEd25519Key(expectedKeyType, key) {
    if (key.type !== expectedKeyType) {
        throw new Error(`Expected key type to be ${expectedKeyType}, but it was "${key.type}".`);
    }
    if (key.asymmetricKeyType !== 'ed25519') {
        throw new Error(`Expected asymmetric key type to be "ed25519", but it was "${key.asymmetricKeyType}".`);
    }
}
